@@ -1,5 +1,8 @@
 #!/usr/bin/env bash
 
+# scrub -std=... flag which conflicts with builds
+export CXXFLAGS=$(echo ${CXXFLAGS:-} | sed -E 's@\-std=[^ ]*@@g')
+
 # The without snapshot comes from the error in
 # https://github.com/nodejs/node/issues/4212.
 ./configure --prefix=$PREFIX --without-snapshot
